@@ -1,31 +1,16 @@
 #!/usr/bin/env python
-# $Id: NameMapper.py,v 1.11 2006/01/15 20:45:22 tavis_rudd Exp $
-"""NameMapper Tests
 
-Meta-Data
-================================================================================
-Author: Tavis Rudd <tavis@damnsimple.com>,
-Version: $Revision: 1.11 $
-Start Date: 2001/10/01
-Last Revision Date: $Date: 2006/01/15 20:45:22 $
-"""
-from __future__ import generators
-__author__ = "Tavis Rudd <tavis@damnsimple.com>"
-__revision__ = "$Revision: 1.11 $"[11:-2]
 import sys
 import types
 import os
 import os.path
 
-import unittest_local_copy as unittest
+import unittest
 from Cheetah.NameMapper import NotFound, valueForKey, \
      valueForName, valueFromSearchList, valueFromFrame, valueFromFrameOrSearchList
 
 
-##################################################
-## TEST DATA FOR USE IN THE TEMPLATES ##
-
-class DummyClass:
+class DummyClass(object):
     classVar1 = 123
 
     def __init__(self):
@@ -48,7 +33,7 @@ class DummyClass:
         
         x = 'A string'
         try:
-            for i in [1,2,3,4]:
+            for i in [1, 2, 3, 4]:
                 if x == 2:	
                     pass
                 
@@ -58,6 +43,10 @@ class DummyClass:
         except:
             raise
 
+class DummyClassGetAttrRaises(object):
+    def __getattr__(self, name):
+        raise ValueError
+
 
 def dummyFunc(arg="Scooby"):
     return arg
@@ -67,52 +56,53 @@ def funcThatRaises():
 
                  
 testNamespace = {
-    'aStr':'blarg',
-    'anInt':1,
-    'aFloat':1.5,
-    'aDict': {'one':'item1',
-              'two':'item2',
-              'nestedDict':{'one':'nestedItem1',
-                            'two':'nestedItem2',
-                            'funcThatRaises':funcThatRaises,
+    'aStr': 'blarg',
+    'anInt': 1,
+    'aFloat': 1.5,
+    'aDict': {'one': 'item1',
+              'two': 'item2',
+              'nestedDict': {'one': 'nestedItem1',
+                            'two': 'nestedItem2',
+                            'funcThatRaises': funcThatRaises,
                             'aClass': DummyClass,
                             },
-              'nestedFunc':dummyFunc,
+              'nestedFunc': dummyFunc,
               },
     'aClass': DummyClass,    
     'aFunc': dummyFunc,
     'anObj': DummyClass(),
+    'anObjThatRaises': DummyClassGetAttrRaises(),
     'aMeth': DummyClass().meth1,
-    'none' : None,  
-    'emptyString':'',
-    'funcThatRaises':funcThatRaises,
+    'none': None,  
+    'emptyString': '',
+    'funcThatRaises': funcThatRaises,
     }
     
-autoCallResults = {'aFunc':'Scooby',
-                   'aMeth':'doo',
+autoCallResults = {'aFunc': 'Scooby',
+                   'aMeth': 'doo',
                    }
 
 results = testNamespace.copy()
-results.update({'anObj.meth1':'doo',
-                'aDict.one':'item1',
-                'aDict.nestedDict':testNamespace['aDict']['nestedDict'],
-                'aDict.nestedDict.one':'nestedItem1',
-                'aDict.nestedDict.aClass':DummyClass,
-                'aDict.nestedFunc':'Scooby',
-                'aClass.classVar1':123,
-                'anObj.instanceVar1':123,
-                'anObj.meth3':'A string',
+results.update({'anObj.meth1': 'doo',
+                'aDict.one': 'item1',
+                'aDict.nestedDict': testNamespace['aDict']['nestedDict'],
+                'aDict.nestedDict.one': 'nestedItem1',
+                'aDict.nestedDict.aClass': DummyClass,
+                'aDict.nestedFunc': 'Scooby',
+                'aClass.classVar1': 123,
+                'anObj.instanceVar1': 123,
+                'anObj.meth3': 'A string',
                 })
 
 for k in testNamespace.keys():
     # put them in the globals for the valueFromFrame tests
-    exec '%s = testNamespace[k]'%k
+    exec('%s = testNamespace[k]'%k)
 
 ##################################################
 ## TEST BASE CLASSES
 
 class NameMapperTest(unittest.TestCase):
-    failureException = (NotFound,AssertionError)
+    failureException = NotFound
     _testNamespace = testNamespace
     _results = results
     
@@ -131,7 +121,7 @@ class NameMapperTest(unittest.TestCase):
 
     def check(self, name):
         got = self.get(name)
-        if autoCallResults.has_key(name):
+        if name in autoCallResults:
             expected = autoCallResults[name]
         else:
             expected = self._results[name]
@@ -331,7 +321,7 @@ class VFN(NameMapperTest):
 
         def test(self=self):
             self.get('anObj.methX')    
-        self.assertRaises(NotFound,test)
+        self.assertRaises(NotFound, test)
         
     def test44(self):
         """NotFound test in a loop"""
@@ -339,7 +329,7 @@ class VFN(NameMapperTest):
             self.get('anObj.methX')    
 
         for i in range(10):
-            self.assertRaises(NotFound,test)
+            self.assertRaises(NotFound, test)
             
     def test45(self):
         """Other exception from meth test"""
@@ -354,7 +344,7 @@ class VFN(NameMapperTest):
             self.get('anObj.meth2')    
 
         for i in range(10):
-            self.assertRaises(ValueError,test)
+            self.assertRaises(ValueError, test)
 
     def test47(self):
         """None in dict lookup"""
@@ -387,7 +377,7 @@ class VFN(NameMapperTest):
             self.get('funcThatRaises')    
 
         for i in range(10):
-            self.assertRaises(ValueError,test)
+            self.assertRaises(ValueError, test)
 
 
     def test53(self):
@@ -403,7 +393,7 @@ class VFN(NameMapperTest):
             self.get('aDict.nestedDict.funcThatRaises')    
 
         for i in range(10):
-            self.assertRaises(ValueError,test)
+            self.assertRaises(ValueError, test)
 
     def test55(self):
         """aDict.nestedDict.aClass in dict lookup"""
@@ -434,6 +424,14 @@ class VFN(NameMapperTest):
         for i in range(10):
             self.get('aDict.nestedDict.funcThatRaises', False)    
 
+    def test61(self):
+        """Accessing attribute where __getattr__ raises shouldn't segfault if something follows it"""
+
+        def test(self=self):
+            self.get('anObjThatRaises.willraise.anything')
+        self.assertRaises(ValueError, test)
+
+
 class VFS(VFN):
     _searchListLength = 1
     
@@ -442,10 +440,10 @@ class VFS(VFN):
         if lng == 1:
             return [self.namespace()]
         elif lng == 2:
-            return [self.namespace(),{'dummy':1234}]
+            return [self.namespace(), {'dummy':1234}]
         elif lng == 3:
             # a tuple for kicks
-            return ({'dummy':1234}, self.namespace(),{'dummy':1234})
+            return ({'dummy':1234}, self.namespace(), {'dummy':1234})
         elif lng == 4:
             # a generator for more kicks
             return self.searchListGenerator()
@@ -453,7 +451,7 @@ class VFS(VFN):
     def searchListGenerator(self):
         class Test:
             pass
-        for i in [Test(),{'dummy':1234}, self.namespace(),{'dummy':1234}]:
+        for i in [Test(), {'dummy':1234}, self.namespace(), {'dummy':1234}]:
             yield i
   
     def get(self, name, autocall=True):
@@ -532,6 +530,17 @@ if sys.platform.startswith('java'):
     del VFF, VFFSL, VFFSL_2, VFFSL_3, VFFSL_4
 
 
+class MapBuiltins(unittest.TestCase):
+    def test_int(self):
+        from Cheetah.Template import Template
+        t = Template('''
+            #def intify(val)
+                #return $int(val)
+            #end def''', compilerSettings={'useStackFrames' : False})
+        self.assertEquals(5, t.intify('5'))
+
+
+
 ##################################################
 ## if run from the command line ##
         
