@@ -1,21 +1,8 @@
 #!/usr/bin/env python
-# $Id: Misc.py,v 1.8 2005/11/02 22:26:08 tavis_rudd Exp $
-"""Miscellaneous functions/objects used by Cheetah but also useful standalone.
-
-Meta-Data
-================================================================================
-Author: Mike Orr <iron@mso.oz.net>
-License: This software is released for unlimited distribution under the
-         terms of the MIT license.  See the LICENSE file.
-Version: $Revision: 1.8 $
-Start Date: 2001/11/07
-Last Revision Date: $Date: 2005/11/02 22:26:08 $
+"""
+    Miscellaneous functions/objects used by Cheetah but also useful standalone.
 """ 
-__author__ = "Mike Orr <iron@mso.oz.net>"
-__revision__ = "$Revision: 1.8 $"[11:-2]
-
 import os          # Used in mkdirsWithPyInitFile.
-import types       # Used in useOrRaise.
 import sys         # Used in die.
 
 ##################################################
@@ -30,7 +17,7 @@ def useOrRaise(thing, errmsg=''):
 
     Called by: Cheetah.Servlet.cgiImport()
     """
-    if type(thing) == types.ClassType and issubclass(thing, Exception):
+    if isinstance(thing, type) and issubclass(thing, Exception):
         raise thing(errmsg)
     return thing
 
@@ -77,6 +64,4 @@ def mkdirsWithPyInitFiles(path):
         f = open(init, 'w') # Open and close to produce empty file.
         f.close()
 
-
-
 # vim: shiftwidth=4 tabstop=4 expandtab
